Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(67)

Unified Diff: sdk/lib/_internal/pub/test/serve/utils.dart

Issue 23645020: Add a hidden option to customize "pub serve"'s hostname. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/_internal/pub/test/serve/utils.dart
diff --git a/sdk/lib/_internal/pub/test/serve/utils.dart b/sdk/lib/_internal/pub/test/serve/utils.dart
index 46ace9de09ed1eb745219c360397cb2feee27184..6c5f1ec0cde0fe120912728ca1175ac97bb7c2c4 100644
--- a/sdk/lib/_internal/pub/test/serve/utils.dart
+++ b/sdk/lib/_internal/pub/test/serve/utils.dart
@@ -92,7 +92,7 @@ class DartTransformer extends Transformer {
/// Returns the `pub serve` process.
ScheduledProcess startPubServe({bool shouldInstallFirst: false}) {
// Use port 0 to get an ephemeral port.
- _pubServer = startPub(args: ["serve", "--port=0"]);
+ _pubServer = startPub(args: ["serve", "--port=0", "--hostname=127.0.0.1"]);
if (shouldInstallFirst) {
expect(_pubServer.nextLine(),
@@ -107,10 +107,10 @@ ScheduledProcess startPubServe({bool shouldInstallFirst: false}) {
return _pubServer;
}
/// Parses the port number from the "Serving blah on localhost:1234" line
/// printed by pub serve.
void _parsePort(String line) {
- var match = new RegExp(r"localhost:(\d+)").firstMatch(line);
+ var match = new RegExp(r"127\.0\.0\.1:(\d+)").firstMatch(line);
assert(match != null);
_port = int.parse(match[1]);
}
@@ -123,7 +123,7 @@ void endPubServe() {
/// verifies that it responds with [expected].
void requestShouldSucceed(String urlPath, String expected) {
schedule(() {
- return http.get("http://localhost:$_port/$urlPath").then((response) {
+ return http.get("http://127.0.0.1:$_port/$urlPath").then((response) {
expect(response.body, equals(expected));
});
}, "request $urlPath");
@@ -133,7 +133,7 @@ void requestShouldSucceed(String urlPath, String expected) {
/// verifies that it responds with a 404.
void requestShould404(String urlPath) {
schedule(() {
- return http.get("http://localhost:$_port/$urlPath").then((response) {
+ return http.get("http://127.0.0.1:$_port/$urlPath").then((response) {
expect(response.statusCode, equals(404));
});
}, "request $urlPath");
@@ -143,7 +143,7 @@ void requestShould404(String urlPath) {
/// that it responds with a 405.
void postShould405(String urlPath) {
schedule(() {
- return http.post("http://localhost:$_port/$urlPath").then((response) {
+ return http.post("http://127.0.0.1:$_port/$urlPath").then((response) {
expect(response.statusCode, equals(405));
});
}, "request $urlPath");
@@ -107,10 +107,10 @@ ScheduledProcess startPubServe({bool shouldInstallFirst: false}) {
return _pubServer;
}
-/// Parses the port number from the "Serving blah on localhost:1234" line
+/// Parses the port number from the "Serving blah on 127.0.0.1:1234" line
/// printed by pub serve.
void _parsePort(String line) {

Powered by Google App Engine
This is Rietveld 408576698